@@ -6,7 +6,7 @@ module JuliaCall
 
 # if Pkg.installed("RCall") == nothing Pkg.add("RCall") end
 
-using Suppressor
+include("./suppress.jl")
 
 @suppress begin
     using RCall
@@ -21,6 +21,9 @@ include("REPLhook.jl")
 include("incomplete_console.jl")
 include("convert.jl")
 include("JuliaObject.jl")
+## include("JuliaArray.jl")
+include("asR.jl")
+include("dispatch.jl")
 
 function transfer_list(x)
     rcopy(RObject(Ptr{RCall.VecSxp}(x)))
@@ -40,8 +43,8 @@ function error_msg(e, bt)
     readstring(m)
 end
 
-function Rerror(fname, e, bt)
-    s1 = join(["Error happens when you try to call function " fname " in Julia.\n"])
+function Rerror(e, bt)
+    s1 = join(["Error happens in Julia.\n"])
     if string(VERSION) < "0.6.0"
         s2 = error_msg(e)
     else
@@ -52,17 +55,17 @@ function Rerror(fname, e, bt)
 end
 
 function docall(call1)
-    call = transfer_list(call1)
-    fname = call[:fname];
-    named_args = call[:named_args]
-    unamed_args = call[:unamed_args]
-    need_return = call[:need_return];
-    show_value = call[:show_value];
     try
+        call = transfer_list(call1)
+        fname = call[:fname];
+        named_args = call[:named_args]
+        unamed_args = call[:unamed_args]
+        need_return = call[:need_return];
+        show_value = call[:show_value];
         if endswith(fname, ".")
             fname = chop(fname);
             f = eval(Main, parse(fname));
-            r = f.(unamed_args...; named_args...);
+            r = f.(unamed_args...);
         else
             f = eval(Main, parse(fname));
             r = f(unamed_args...; named_args...);
@@ -79,7 +82,7 @@ function docall(call1)
             RObject(nothing).p;
         end;
     catch e
-        Rerror(fname, e, catch_stacktrace()).p;
+        Rerror(e, catch_stacktrace()).p;
     end;
 end
 
